@@ -32,7 +32,7 @@ require_once 'include/version.php';
 
 function cmpReps($a, $b) {
 	// First, sort by group
-	$g = strcasecmp($a->group, $b->group);
+	$g = strcasecmp((string) $a->group, (string) $b->group);
 	if ($g) return $g;
 
 	// Same group? Sort by name
@@ -44,7 +44,7 @@ function cmpReps($a, $b) {
 // {{{ cmpGroups($a, $b)
 
 function cmpGroups($a, $b) {
-	$g = strcasecmp($a->group, $b->group);
+	$g = strcasecmp((string) $a->group, (string) $b->group);
 	if ($g) return $g;
 
 	return 0;
@@ -1023,21 +1023,6 @@ class WebSvnConfig {
 
 	function getTempDir() {
 		if (empty($this->tempDir)) {
-			if (!function_exists('sys_get_temp_dir')) {
-				function sys_get_temp_dir() {
-					if (($tmp = getenv('TMPDIR')) ||
-						($tmp = getenv('TMP')) ||
-						($tmp = getenv('TEMP')) ||
-						($tmp = ini_get('upload_tmp_dir')))
-						return $tmp;
-					$tmp = tempnam(__FILE__, '');
-					if (file_exists($tmp)) {
-						unlink($tmp);
-						return dirname($tmp);
-					}
-					return null;
-				}
-			}
 			$this->tempDir = sys_get_temp_dir();
 		}
 		return $this->tempDir;
@@ -1102,7 +1087,7 @@ class WebSvnConfig {
 		list($base, $params) = $this->getUrlParts($rep, $path, $op);
 		$url = $base.'?';
 		foreach ($params as $k => $v) {
-			$url .= $k.'='.urlencode($v).'&amp;';
+			$url .= $k.'='.rawurlencode($v).'&amp;';
 		}
 		return $url;
 	}
@@ -1134,7 +1119,7 @@ class WebSvnConfig {
 			if ($op == 'index') {
 				$url .= '/';
 			} else if (is_object($rep)) {
-				$url .= '/'.$rep->getDisplayName().str_replace('%2F', '/', rawurlencode($path));
+				$url .= '/'.$rep->getDisplayName().str_replace('%2F', '/', rawurlencode($path ?? ''));
 
 				if ($op && $op != 'dir' && $op != 'file') {
 					$params['op'] = $op;
