@@ -50,8 +50,8 @@ function createPathLinks($rep, $path, $rev, $peg = '') {
 	$rootName = $lang['BREADCRUMB_REPO_ROOT'];
 
 	$vars['path_links']				= '';
-	$vars['path_links_root_root']	= "<a href=\"${pathSoFarURL}\" class=\"root\"><span>${rootName}</span></a>";
-	$vars['path_links_root_repo']	= "<a href=\"${pathSoFarURL}\" class=\"root\"><span>${repoName}</span></a>";
+	$vars['path_links_root_root']	= "<a href=\"{$pathSoFarURL}\" class=\"root\"><span>{$rootName}</span></a>";
+	$vars['path_links_root_repo']	= "<a href=\"{$pathSoFarURL}\" class=\"root\"><span>{$repoName}</span></a>";
 	$vars['path_links_root_config']	= $config->getBreadcrumbRepoRootAsRepo()
 										? $vars['path_links_root_repo']
 										: $vars['path_links_root_root'];
@@ -344,13 +344,13 @@ function buildQuery($data, $separator = '&amp;', $key = '') {
 		$data = get_object_vars($data);
 	$p = array();
 	foreach ($data as $k => $v) {
-		$k = urlencode($k);
+		$k = rawurlencode($k);
 		if (!empty($key))
 			$k = $key.'['.$k.']';
 		if (is_array($v) || is_object($v)) {
 			$p[] = buildQuery($v, $separator, $k);
 		} else {
-			$p[] = $k.'='.urlencode($v);
+			$p[] = $k.'='.rawurlencode($v);
 		}
 	}
 	return implode($separator, $p);
@@ -456,7 +456,7 @@ function tempnamWithCheck($dir, $prefix, $rmOnShutdown = true) {
 	}
 	if ($tmp && $rmOnShutdown)
 	{
-		register_shutdown_function(removeDirectory, $tmp);
+		register_shutdown_function('removeDirectory', $tmp);
 		return $tmp;
 	}
 
