@@ -29,6 +29,8 @@ $lang["LANGUAGENAMEENGLISH"] = "Indonesian";
 $lang["LANGUAGENAMENATIVE"] = "Bahasa Indonesia";
 $lang["LANGUAGENAMEHTML"] = "Bahasa Indonesia";
 
+$lang['BREADCRUMB_REPO_ROOT'] = '(root)';
+
 $lang["LOG"] = "Log";
 $lang["DIFF"] = "Perbedaan";
 
@@ -117,3 +119,7 @@ $lang["COMPPATH"] = "Bandingkan Path:";
 $lang["WITHPATH"] = "Dengan Path:";
 $lang["FILEDELETED"] = "File dihapus";
 $lang["FILEADDED"] = "File baru";
+
+$lang['SEARCH'] = "Cari";
+$lang['SEARCH_PLACEHOLDER'] = "Cari item di sini";
+$lang['NOITEMSFOUND'] = "Tidak Ada Item yang Ditemukan";
